Numerical integrators
=====================

``NumpyBrain`` provides several explicit and implicit methods for
the numerical integration of Ordinary Differential Equations (ODEs)
and Stochastic Differential Equations (SDEs).

Numerical methods for ordinary differential equations

- `ode_euler <../apis/_autosummary/npbrain.core.ode_euler.rst>`_
- `ode_rk2 <../apis/_autosummary/npbrain.core.ode_rk2.rst>`_
- `midpoint <../apis/_autosummary/npbrain.core.midpoint.rst>`_
- `ode_heun <../apis/_autosummary/npbrain.core.ode_heun.rst>`_
- `ode_rk3 <../apis/_autosummary/npbrain.core.ode_rk3.rst>`_
- `ode_rk4 <../apis/_autosummary/npbrain.core.ode_rk4.rst>`_
- `ode_rk4_alternative <../apis/_autosummary/npbrain.core.ode_rk4_alternative.rst>`_
- `ode_backward_euler <../apis/_autosummary/npbrain.core.ode_backward_euler.rst>`_
- `trapezoidal_rule <../apis/_autosummary/npbrain.core.trapezoidal_rule.rst>`_
- `ode_exponential_euler <../apis/_autosummary/npbrain.core.ode_exponential_euler.rst>`_

Numerical methods for stochastic differential equations

- `sde_euler <../apis/_autosummary/npbrain.core.sde_euler.rst>`_
- `Milstein_dfree_Ito <../apis/_autosummary/npbrain.core.Milstein_dfree_Ito.rst>`_
- `sde_heun <../apis/_autosummary/npbrain.core.sde_heun.rst>`_
- `Milstein_dfree_Stra <../apis/_autosummary/npbrain.core.Milstein_dfree_Stra.rst>`_
- `sde_exponential_euler <../apis/_autosummary/npbrain.core.sde_exponential_euler.rst>`_
- `sde_rk2` (coming soon)
- `sde_rk3` (coming soon)
- `sde_rk4` (coming soon)

